@@ -58,8 +58,12 @@ except ImportError:
 
 import urllib.request
 from xml.etree.ElementTree import ElementTree
-from xml.etree.ElementTree import ParseError
 from xml.parsers.expat import ExpatError
+try:
+    from xml.etree.ElementTree import ParseError
+except:
+    class ParseError(Exception):
+        pass
 
 if platform.system() == 'Windows':
     # Curses is not available on Windows
